@@ -2,11 +2,8 @@
 #![deny(missing_docs)]
 #![deny(clippy::all)]
 // #![warn(clippy::pedantic)]
-//! # persist-es
+#![doc = include_str!("../README.md")]
 //!
-//! > Common persistence logic used for database-backed event stores for [cqrs-es.](https://crates.io/crates/cqrs-es).
-//!
-// #![doc = include_str!("../README.md")]
 mod context;
 mod error;
 mod event_store;
