@@ -1,37 +1,35 @@
-use crate::{PersistenceError, QueryContext, SnapshotStoreAggregateContext};
+use crate::{PersistenceError, QueryContext, SerializedEvent, SerializedSnapshot};
 use async_trait::async_trait;
-use cqrs_es::{Aggregate, EventEnvelope, View};
+use cqrs_es::{Aggregate, View};
+use serde_json::Value;
 
 /// Handles the database access needed for operation of a PersistedSnapshotStore.
 #[async_trait]
-pub trait PersistedEventRepository<A>: Send + Sync
-where
-    A: Aggregate,
-{
+pub trait PersistedEventRepository: Send + Sync {
     /// Returns all events for a single aggregate instance.
-    async fn get_events(
+    async fn get_events<A: Aggregate>(
         &self,
         aggregate_id: &str,
-    ) -> Result<Vec<EventEnvelope<A>>, PersistenceError>;
+    ) -> Result<Vec<SerializedEvent>, PersistenceError>;
 
     /// Returns the last events for a single aggregate instance.
-    async fn get_last_events(
+    async fn get_last_events<A: Aggregate>(
         &self,
         aggregate_id: &str,
         number_events: usize,
-    ) -> Result<Vec<EventEnvelope<A>>, PersistenceError>;
+    ) -> Result<Vec<SerializedEvent>, PersistenceError>;
 
     /// Returns the current snapshot for an aggregate instance.
-    async fn get_snapshot(
+    async fn get_snapshot<A: Aggregate>(
         &self,
         aggregate_id: &str,
-    ) -> Result<Option<SnapshotStoreAggregateContext<A>>, PersistenceError>;
+    ) -> Result<Option<SerializedSnapshot>, PersistenceError>;
 
     /// Commits the updated aggregate and accompanying events.
-    async fn persist(
+    async fn persist<A: Aggregate>(
         &self,
-        events: &[EventEnvelope<A>],
-        snapshot_update: Option<(String, A, usize)>,
+        events: &[SerializedEvent],
+        snapshot_update: Option<(String, Value, usize)>,
     ) -> Result<(), PersistenceError>;
 }
 
